<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Contest;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use App\Sola;
use App\Dovoljenje;
use App\ActivatedContest;
use App\Rezultat;
use Illuminate\Support\Facades\Config;

/**
     * @group Admin panel, to manage contests
     */


class ContestController extends Controller
{
    /**
     * Print results of the current contest
     */

    public function getResults($id){

        $results = DB::select(DB::raw("SELECT D.kodaSole,D.razred,D.priimek,D.ime,D.username,D.email,T.* FROM
(SELECT dijak_id, SUM(tocke) as tocke, SUM(numTestCasePassed) as totTest,SUM(numPrimaryTestPassed) as totPrimary,AVG(stTestiranj) as avgTests FROM rezultat WHERE contest_id = $id
GROUP BY dijak_id ) as T JOIN dijaki as D ON(T.dijak_id = D.id) ORDER BY D.kodaSole,D.razred,T.tocke"));

// ,'numTestCasePassed','numPrimaryTestPassed','stTestiranj')
         return view('printResult')->with('results',$results);

    }

    /**
     * Activate the specific contest
     */
    //aktivacija in deaktivacija kontesta
    public function activate($id){
        
        $res=ActivatedContest::where('id',1)->delete();

        $contest = ActivatedContest::create([
                    'id' => 1,
                    'contest_id' => $id
                ]);
        $contest->save();

        return redirect()->action(
            'ContestController@show', ['id' => $id]
        );
    }

    /**
     * Deactivate the specific contest
     */

    public function deActivate($id){
        
        $res=ActivatedContest::where('id',1)->delete();


        return redirect()->action(
            'ContestController@show', ['id' => $id]
        );
    }


    /**
     * Display aall the contests
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
         //
        $contesti = Contest::orderBy('id','desc')->get();

        return view('contest')->with('contesti',$contesti);
    }

    /**
     * Return the view for the creation of a new contest
     */

    public function createContest(){
        $prikaziForm = true;
        return view('contest')->with('ustvari',$prikaziForm);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created contest in the DB
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        DB::beginTransaction();


        try{

            $contest = Contest::create([
                    'ime' => $request->ime,
                    'trajanje' => Carbon::parse(Carbon::parse($request->trajanje)->format('H:i:s')),
                    'zacetek' => Carbon::parse($request->zacetek)
                ]);
            $contest->save();


            DB::commit();
            return redirect()->action('ContestController@index');

        }catch(\Exception $e){
            DB::rollback();
            dump($e);
            return view('contest')->with('message','Error during creation of contest');
        }
    }

    /**
     * Display a specific contest defined by the ID, if message is present display also the warning message
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id,$message = null)
    {

        $contest = Contest::find($id);

        //prejmemo contestID ki je aktiviran
        $contestID = ActivatedContest::find(1);

        if(isset($contestID) && intval($contestID->contest_id) === intval($contest->id)){
            $isActive = true;
        }else{
            $isActive = false;
        }

        $dovoljenja = Dovoljenje::where('contest_id',$id)
            ->join('sola','dovoljenje.sola_id','=','sola.id')
            ->select('dovoljenje.id as dovoljenje_id','sola.nazivSole','sola.kodaSole','dovoljenje.razred','dovoljenje.zacetek','dovoljenje.konec')
            ->orderBy('nazivSole','ASC')
            ->orderBy('razred','DESC')
            ->get();

        if($dovoljenja->count() > 0){
            if($message !== null){
                $contestData = array("contest" => $contest,"isActive"=>$isActive,"dovoljenja"=>$dovoljenja,"message"=>$message);
            }else{
                $contestData = array("contest" => $contest,"isActive"=>$isActive,"dovoljenja"=>$dovoljenja);
            }
        }else{
            if($message !== null){
                $contestData = array("contest" => $contest,"isActive"=>$isActive,"message"=>$message);
            }else{
                $contestData = array("contest" => $contest,"isActive"=>$isActive);
            }
        }

        $problemi = Contest::find($id)->problem()
        ->join('jezik_navodil','problem.id','=','jezik_navodil.problem_id')
        ->where('jezik_navodil.jezikNavodil','=','slo')
        ->select('problem.id','jezik_navodil.naslov','vrstniRed')
        ->orderBy('vrstniRed','ASC')
        ->get();
        
        if($problemi->count() > 0){

            $contestData["problemi"]=$problemi;
        }

        return view('contest')->with('prikaziContest',$contestData);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified contest 
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        DB::beginTransaction();
        try{

            $contest = Contest::find($id);
            $contest->ime = $request->ime;
            $contest->zacetek = Carbon::parse($request->zacetek);
            if($request->trajanje !== "unchanged"){
                $contest->trajanje = Carbon::parse(Carbon::parse($request->trajanje)->format('H:i:s'));
            }

            $contest->save();


            DB::commit();
            return redirect()->action(
                'ContestController@show', ['id' => $id,
                                            'message' => 'Contest modified succesfully']);

        }catch(\Exception $e){
            DB::rollback();
            dump($e);
            return view('contest')->with('message','Error during modification of contest');
        }
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
