<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Contest;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;
use App\Sola;
use App\Dovoljenje;
use App\ActivatedContest;
use Illuminate\Support\Facades\Config;


/**
     * @group Admin panel, to manage permissions to compete
     */


class DovoljenjeController extends Controller
{



    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Show the view for the creation of a new permission
     */
    //prikazi stran za ustvarjanje dovoljenja interaktivna stran z JS
    //prejme contestID
    public function addDovoljenje($id){

        //pridobi vse kode sole
        $Sole = Sola::get();
        
        $contest = Contest::find($id);

        $dovoljenjeData = array("contest" => $contest,"sole"=>$Sole);
        return view('contest')->with('ustvariDovoljenje',$dovoljenjeData);
    }

    /**
     * Store a newly created permission
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
        //shrani dovoljenje
    public function store(Request $request,$id){

        //kodaSole ni napak v resnici je id sole!!!
        $dovoljenje = Dovoljenje::where('sola_id','=',$request->kodaSole)
            ->where('contest_id','=',$id)
            ->where('razred','=',$request->razred)->get();

        //preverimo ali ze obstaja razred za to solo, da ne vnasamo veckrat!!!
        if($dovoljenje->count()>0){
            return redirect()->action(
                'ContestController@show', ['id' => $id,
                                            'message' => 'Razred za to solo ze obstaja']
            );
        }
        //pregledamo se da cas se ne kriza
        if(Carbon::parse($request->konec)->lessThan(Carbon::parse($request->zacetek))){
            return redirect()->action(
                'ContestController@show', ['id' => $id,
                                            'message' => 'Postavil si napacen zacetek oziroma konec kontesta']
            );
        }



        DB::beginTransaction();



        try{

            $dovoljenje = Dovoljenje::create([
                    'razred' => $request->razred,
                    'zacetek' => Carbon::parse($request->zacetek),
                    'konec' => Carbon::parse($request->konec),
                    'contest_id' => $id,
                    'sola_id' => $request->kodaSole
                ]);
            $dovoljenje->save();


            DB::commit();
            return redirect()->action(
                'ContestController@show', ['id' => $id,
                                            'message' => 'Dovoljenje created succesfully']
            );

        }catch(\Exception $e){
            DB::rollback();
            dump($e);
            return view('contest')->with('message','Error during creation of dovoljenje');
        }

    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing a permission
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $dovoljenje = Dovoljenje::where('dovoljenje.id',$id)
        ->join('sola','sola.id','=','dovoljenje.sola_id')
        ->select('dovoljenje.id as dov_id','sola.nazivSole','dovoljenje.sola_id','sola.kodaSole','dovoljenje.razred','dovoljenje.zacetek','dovoljenje.konec','dovoljenje.contest_id')
        ->first();
        


        $Sole = Sola::get();
        

        $dovoljenje = array("dov" => $dovoljenje,"sole"=>$Sole);
        return view('contest')->with('dov',$dovoljenje);

    }

    /**
     * Update the specified permission
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //kodaSole ni napak v resnici je id sole!!!
        $dovoljenje = Dovoljenje::where('sola_id','=',$request->kodaSole)
            ->where('razred','=',$request->razred)
            ->where('dovoljenje.id','!=',$id)
            ->get();

        //preverimo ali ze obstaja razred za to solo, da ne vnasamo veckrat!!!
        if($dovoljenje->count()>0){
            return redirect()->action(
                'ContestController@show', ['id' => $request->contest_id,
                                            'message' => 'Razred za to solo ze obstaja']
            );
        }
        //pregledamo se da cas se ne kriza
        if(Carbon::parse($request->konec)->lessThan(Carbon::parse($request->zacetek))){
            return redirect()->action(
                'ContestController@show', ['id' => $request->contest_id,
                                            'message' => 'Postavil si napacen zacetek oziroma konec kontesta']
            );
        }


        DB::beginTransaction();



        try{

            $dovoljenje = Dovoljenje::find($id);
            $dovoljenje->razred = $request->razred;
            $dovoljenje->zacetek = Carbon::parse($request->zacetek);
            $dovoljenje->konec = Carbon::parse($request->konec);
            //v resnici ni koda sole ma id
            $dovoljenje->sola_id = $request->kodaSole;
            $dovoljenje->save();


            DB::commit();
            return redirect()->action(
                'ContestController@show', ['id' => $request->contest_id,
                                            'message' => 'Dovoljenje updated succesfully']
            );

        }catch(\Exception $e){
            DB::rollback();
            dump($e);
            return view('contest')->with('message','Error during updating of dovoljenje');
        }


    }

    /**
     * Remove the specified permission from the DB
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($dovoljenje_id,$contest_id)
    {
        $dovoljenje = Dovoljenje::find($dovoljenje_id)->delete();

        return redirect()->action(
                'ContestController@show', ['id' => $contest_id,
                                            'message' => 'Dovoljenje deleted succesfully']
            );
    }
}
