<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\dijak;
use App\Sola;
use Illuminate\Support\Facades\Input;
use Illuminate\Support\Facades\Mail;
use Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Database\Eloquent\ModelNotFoundException;
use App\Mail\EmailVerification;
use App\Mail\EmailPasswordReset;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Session;
use DB;


/**
* @group Login/Register management
*
* APIs for Login, Register users
*/


class loginController extends Controller
{
	/**
     * Return the view containing the login register page.
     */
    function loginregister(){
    	return view('loginregister');
    }

    /**
     * Return the view to change the password 
     *	the token identifies the user
     */

    function resetPassword($token){
    	return view('passwordreset', ['Oldtoken' => $token]);
    }

    /**
     * reset password
     *	by sending an email with modify password option and update the pwd in DB
     */

    function reset(Request $request){
		//reset password
    	//1.idea send email with new password and update the pwd in DB

		$dijak = dijak::where('email',Input::get('email'))->first();
		$token = $dijak->email_token_verification;
		$username = $dijak->username;


		$email = new EmailPasswordReset($token, $username);//WATCH THIS OUT IF THE TOKEN DOESNT CHANGE
    	Mail::to(Input::get('email'))->send($email);
		return redirect()->back()->with('message', 'Check your email! We have sent you something.');

    }

    /**
     * Change the password of the user, important to check the token of the user
     */

    function newPassword(Request $request){
    	//check the token verification
 		$input = [
	        'password'          	=> Input::get('password'),
	        'password_confirmation'  => Input::get('password_confirmation')
	    ];
	 		//create the rules for the inputs
	    $rules = [
	        'password'          => 'required|required_with:password_confirmation|min:8|confirmed',
	        'password_confirmation' => 'min:8|same:password',
	    ];
	 
	 	//validate the inputs upon the rules
	    $validation = Validator::make($input, $rules);
	 

	    if($validation->passes()) {
	    	$dijak = dijak::where('email_token_verification',Input::get('Oldtoken'))->first();
	    	if(isset($dijak)){
				//change password
				DB::table('dijaki')->where('id', $dijak->id)
	            						->update([
	            							'password' => Hash::make(Input::get('password')), 
	            							'email_token_verification' => Input::get('_token')
	            					]);
	           	return redirect('/loginregister')->with('message', 'Password changed!');
            }else{
            	return Redirect::to('/loginregister')
	    				->withErrors(['Woooah! Something is really not right here!']);
			}

		}else{
	        $errors = $validation->errors();
	 
	        return back()->withErrors($errors);
		}
	}

	/**
     * Verify the user after the first registration
     */

	function verification($token){
		//check the tokens if they are the same
		$dijakObstaja = dijak::where('email_token', $token)->first();
		if(isset($dijakObstaja)){
			if($dijakObstaja->email_verified == false){
				//update table
				DB::table('dijaki')->where('id', $dijakObstaja->id)
            						->update(['email_verified' => true]);
				return redirect('/loginregister')->with('message', 'Email verification succeded!');

			}else{
				return redirect('/loginregister')->with('message', 'Email already verified!');
			}

		}else{
			return redirect('/loginregister')->withErrors('There has been an error with your email address.');
		}
	}

	/**
     * Perform the login and redirect to the begin page.
     */

	function login(Request $request){
		
			$hashedPassword = dijak::where('email','=',Input::get('email'))->first();
			if ($hashedPassword && Hash::check(Input::get('password'), $hashedPassword->password)) {

				if(!$hashedPassword->email_verified){
					return Redirect::to('/loginregister')
	    				->withInput()
	    				->withErrors(['Email not verified']);
				}

				Session::put('dijak_id', $hashedPassword->id);
				Session::put('username', $hashedPassword->username);
					return Redirect::to('/begin');
					/*Redirect::to('/solve')
			    				->with('message', 'Login succeded!');*/
			}else{
				return Redirect::to('/loginregister')
	    				->withInput()
	    				->withErrors(['Email or Password mismatch']);
			}

	}

	/**
     * Destroy the session of the use and Logout from the system, then redirect to welcome page
     */

	function logout(Request $request){

		$request->session()->flush();

		return Redirect::to('/');

	}


	/**
     * Register a new user and redirect to LoginRegister
     */

    function register(Request $request){
    	//get the inputs from the register form
	    $input = [
	        'ime'        			=> Input::get('name'),
	        'priimek'         		=> Input::get('surname'),
	        'email'             	=> Input::get('email'),
	        'password'          	=> Input::get('password'),
	        'password_confirmation'  => Input::get('password_confirmation'),
	        'username' 				=> Input::get('username'),
	        'razred'				=> Input::get('school-class'),
	        'kodasole'				=> Input::get('school-code')
	    ];
	 		//create the rules for the inputs
	    $rules = [
	        'ime'        		=> 'required|alpha|max:100|min:2',
	        'priimek'         	=> 'required|alpha|max:100',
	        'email'             => 'required|email',
	        'password'          => 'required|required_with:password_confirmation|min:8|confirmed',
	        'password_confirmation' => 'min:8|same:password',
	        'username'			=> 'required|max:100|alpha_num',
	        'razred'			=> 'required|integer|between:1,5',
	        'kodasole'			=> 'required|alpha_num|size:8|'
	    ];
	 
	 		//validate the inputs upon the rules
	    $validation = Validator::make($input, $rules);
	 
	    $dijak = new dijak();

	    if($validation->passes()) {
			//check if the record already exist in DB
	    	try {
	    		$inserted = dijak::where('email', '=', Input::get('email'))->first();
	    	} catch (ModelNotFoundException $ex) {
				$inserted = null;
			}
	    	if(!(is_null($inserted))){
	       		return Redirect::to('/loginregister')
	    				->withInput()
	    				->withErrors(['Email already choosen']);
	    	}

    		//check and get foreign key
	    	try {
	    		$id_sola_check = Sola::where('kodaSole', '=', Input::get('school-code'))->first();
	    	} catch (ModelNotFoundException $ex) {
				//$id_sola_check = null;//WHAT HAPPENED HERE CHECK
			}
	    	if(is_null($id_sola_check)){
	       		return Redirect::to('/loginregister')
	    				->withInput()
	    				->withErrors(['School code not valid!']);
	    	}


	 		//insert into DB new data
	    	$dijak->ime = Input::get('name');
	    	$dijak->priimek = Input::get('surname');
	    	$dijak->username = request('username');
	    	$dijak->password = Hash::make(Input::get('password')); 
	    	$dijak->email = Input::get('email');
	    	$dijak->datumVpisa = Carbon::now();
	    	$dijak->sola_id = $id_sola_check->id;
	    	$dijak->email_token = Input::get('_token');
	    	$dijak->email_token_verification = Input::get('_token');
	    	$dijak->razred = Input::get('school-class');
	    	$dijak->kodasole = Input::get('school-code');

	    	$dijak->save();

	    	try{
				//check if the query got executed correctly -> hint check if exist in table
	    		$inserted = dijak::where('email', '=', Input::get('email'))->first();
	    	} catch (ModelNotFoundException $ex) {
	    		$inserted = null;
		    }

	    	if(is_null($inserted)){
	    		return Redirect::to('/loginregister')
	    				->withInput()
	    				->withErrors(['A problem occured inserting new data!']);
	    	}else{



	    		//need to send verification email and success
	    		$email = new EmailVerification($dijak->email_token, $dijak->username);//WATCH THIS OUT IF THE TOKEN DOESNT CHANGE
            	Mail::to($dijak->email)->send($email);
	    		return redirect()->back()->with('message', 'Registration succeded! Verification email sent!');
	    	}

	    } else {
	        $errors = $validation->errors();
	 
	        return Redirect::to('/loginregister')->withErrors($errors);
	    }

    }

}
