<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Problem;
use App\JezikNavodil;
use App\Koda;
use App\ProblemMeseca;
use App\ContestProblem;
use Illuminate\Support\Facades\DB;

/**
     * @group Admin panel, to manage problems
     */


class problemController extends Controller
{
    /**
     * Show the data about a problem
     */

	public function show($problemID){

		$tezavnostProblema = Problem::find($problemID)->tezavnostProblema;

		$prog = DB::table('problem')
    		->join('koda','problem.id','=','koda.problem_id')
    		->where('problem.id',$problemID)
    		->select('problem.id','koda.id','jezikProgramski','kodaHead','kodaBody','kodaTail')
    		->get();

    	$navod = DB::table('problem')
			->join('jezik_navodil','problem.id','=','jezik_navodil.problem_id')
    		->select('problem.id','jezik_navodil.id','naslov','navodila','jezikNavodil')
    		->where('problem.id',$problemID)
    		->get();


		return view('problem')->with(['prog' => $prog,
										'navod' => $navod,
										'tezavnostProblema' => $tezavnostProblema,
										'problemID' => $problemID

									]);


	}

    /**
     * Return all existing problems in the view problem
     */

    //MORA IMETI SLOVENSKA NAVODILA DRUGAce problem NI prikazan!!!
    public function index(){

    	$problems = Problem::join('jezik_navodil','problem.id','=','jezik_navodil.problem_id')
    		->where('jezik_navodil.jezikNavodil','slo')
    		->select('problem.id','jezik_navodil.naslov','problem.tezavnostProblema')
    		->orderBy('problem.id','desc')
    		->get();



    	return view('problem')->with('problems',$problems);
    }

    /**
     * Delete a defined problem by the ID
     */

    public function delete($problemID){

        $delete = true;


        $inContest = ContestProblem::where('problem_id',$problemID)->first();

        if($inContest !== null){
            error_log("in a contest");
            $delete = false;
        }

        $inMesecP = ProblemMeseca::where('problem_id',$problemID)->first();
        if($inMesecP !== null){
            error_log("in a problem meseca");
            $delete = false;
        }

        if($delete){
            error_log("brisanje");
            JezikNavodil::where('problem_id',$problemID)->delete();
            Koda::where('problem_id',$problemID)->delete();
            Problem::where('id',$problemID)->delete();
            return '{"deleted":"true"}';
        }else{
            return '{"deleted":"false"}';
        }



    }

    /**
     * Update the data about a problem
     */

    public function update($problemID,Request $request){

    		//associativni array za dostop do podatkov
    	$arr = json_decode($request->getContent(),true);

    	$tezavnostProblema = $arr['tezavnostProblema'];

    	//error_log($arr["jezik"."0"]['jezikNavodil']);


    	DB::beginTransaction();

    	try{

    		$problem = Problem::find($problemID);

    		if($problem->tezavnostProblema != $tezavnostProblema){

    			$problem->tezavnostProblema = $tezavnostProblema;
    			$problem->save();
    		}

    		$n = 0;

    		while(array_key_exists("problem".strval($n),$arr)){

    			//posodobi
    			if($arr["problem".strval($n)]['id'] !== "undf"){

    				$kodaProblem = Koda::find($arr["problem".strval($n)]['id']);

    				$kodaProblem->jezikProgramski=$arr["problem".strval($n)]['jezikProgramski'];
    				$kodaProblem->kodaHead=$arr["problem".strval($n)]['kodaHead'];
    				$kodaProblem->kodaBody=$arr["problem".strval($n)]['kodaBody'];
    				$kodaProblem->kodaTail=$arr["problem".strval($n)]['kodaTail'];

    				$kodaProblem->save();
    				error_log("updated koda");

    			}else{//drugace ustvari novo kodo

    				$kodaProblem = Koda::create([
    					'jezikProgramski' => $arr["problem".strval($n)]['jezikProgramski'],
    					'kodaHead' => $arr["problem".strval($n)]['kodaHead'],
    					'kodaBody' => $arr["problem".strval($n)]['kodaBody'],
    					'kodaTail' => $arr["problem".strval($n)]['kodaTail'],
	    				'problem_id' => $problem->id
    				]);
    				$kodaProblem->save();
    				//error_log($arr["problem".strval($n)]['kodaHead']);
    				error_log("added koda");

    			}
    			$n++;
    		}

    		if($n==0){
    			throw new \Exception('no code');
    		}

    		$n = 0;

    		while(array_key_exists("jezik".strval($n),$arr)){

    			//ce id obstaja posodobi
    			if($arr["jezik".strval($n)]['id'] !== "undf"){
    				$navodilaProblema = JezikNavodil::find($arr["jezik".strval($n)]['id']);

    				$navodilaProblema->naslov = $arr["jezik".strval($n)]['naslov'];
    				$navodilaProblema->jezikNavodil = $arr["jezik".strval($n)]['jezikNavodil'];
    				$navodilaProblema->navodila = $arr["jezik".strval($n)]['navodila'];

    				$navodilaProblema->save();

    				error_log("updated navodila");

    			}else{//drugace ustvari novega
    				$navodilaProblema = JezikNavodil::create([
    					'naslov' => $arr["jezik".strval($n)]['naslov'],
    					'jezikNavodil' => $arr["jezik".strval($n)]['jezikNavodil'],
    					'navodila' => $arr["jezik".strval($n)]['navodila'],
    					'problem_id' => $problem->id
    				]);
    				$navodilaProblema->save();

    				error_log("added navodila");
    			}
    			$n++;

    		}

    		if($n==0){
    			throw new \Exception('no navodila');
    		}

    		DB::commit();
            return '{"error":"no error"}';

    	}catch(\Exception $e){
    		DB::rollback();
    		return '{"error":"napaka v vstavljanju"}';
    	}



    	return '{"error":"ok"}';

    }

    /**
     * Create a new problem
     */

    public function create(Request $request){
    		//associativni array za dostop do podatkov
    	$arr = json_decode($request->getContent(),true);

    	$tezavnostProblema = $arr['tezavnostProblema'];

    	DB::beginTransaction();

    	try{

    		$problem = Problem::create([
    			'tezavnostProblema' => intval($tezavnostProblema)
    		]);

    		$problem->save();


    		$n = 0;

    		while(array_key_exists("problem".strval($n),$arr)){

    			$kodaProblem = Koda::create([
    				'jezikProgramski' => $arr["problem".strval($n)]['jezikProgramski'],
    				'kodaHead' => $arr["problem".strval($n)]['kodaHead'],
    				'kodaBody' => $arr["problem".strval($n)]['kodaBody'],
    				'kodaTail' => $arr["problem".strval($n)]['kodaTail'],
    				'problem_id' => $problem->id
    			]);
    			$kodaProblem->save();
    		//error_log($arr["problem".strval($n)]['kodaHead']);
    			$n++;
    			error_log("med");
    		}

    		if($n==0){
    			throw new \Exception('no code');
    		}

    		$n = 0;

    		error_log("pred");
    		while(array_key_exists("jezik".strval($n),$arr)){

    			$navodilaProblema = JezikNavodil::create([
    				'naslov' => $arr["jezik".strval($n)]['naslov'],
    				'jezikNavodil' => $arr["jezik".strval($n)]['jezikNavodil'],
    				'navodila' => $arr["jezik".strval($n)]['navodila'],
    				'problem_id' => $problem->id
    			]);
    			$navodilaProblema->save();

    			$n++;
    		}

    		if($n==0){
    			throw new \Exception('no navodila');
    		}

    		DB::commit();
            return '{"error":"no error"}';

    	}catch(\Exception $e){
    		DB::rollback();
    		return '{"error":"napaka v vstavljanju"}';
    	}

    }


}